#ifndef DlgSlider_included
#define DlgSlider_included

#include <qstring.h>
#include <qstrlist.h>

#include "widget/DlgWidget.h"
#include "widget/Slider.h"

class DlgSlider : public DlgWidget
{

public:

    DlgSlider
    (
	QWidget*	parentWidget,
	const char*	name = NULL
    );

    virtual ~DlgSlider();
    
    virtual QWidget* GetWidget( void );
    // return the DlgSlider's widget

    virtual int DoPropertyDialog( QWidget *, char * );
    // Do the property dialog

    virtual void SaveContents
    (
	QTextStream&	stream
    );
    // save the contents of the widget

    static void SaveQt
    (
       QTextStream &,
       const QSlider *
    );
    // Used by original Qt subclasses

    static bool RestoreQt
    (
       const QString &,
       const QString &,
       QSlider *
    );
    // Used by original Qt subclasses

    virtual bool RestoreKeyValue( QString &key, QString &value );
    // Restore a single key/value pair

    virtual QString GetHeaderFilename() const;
    // return the header filename for the widget

    virtual QString GetWidgetClass() const;
    // return the class name for the widget

    virtual void GenerateSource
    (
	QTextStream&		stream,
	const QString&		varName,
	const QList<DlgWidget>&	zOrdering
    );
    // call GenSrc for the appropriate widget base classes. varName already
    // has a leading tab and the correct dereferencer

    static void GenSrc
    (
	DlgWidget&		dlgWidget,
	QTextStream&		stream,
	const QString&		varName,
	const QList<DlgWidget>&	zOrdering
    );
    // static method to actually generate the source

    virtual void AddSignalsToList( QStrList&	signalList ) const;
    // add signals specific to a particular widget type to the list
    
    static const QStrList& GetSignalList( void );
    // method to return the list of signals

private: // static data

    static QStrList	itsSignals;
    // list of the signals that can be connected to this widget

private:

    Slider*	itsWidget;

    static int itsNextWidgetNum;
    // number of the next widget

};


inline QWidget* DlgSlider::GetWidget( void )
{
    return itsWidget;
}


inline QString DlgSlider::GetHeaderFilename() const
{
    return "<qslider.h>";
}

inline QString DlgSlider::GetWidgetClass() const
{
    return "QSlider";
}

inline void DlgSlider::GenerateSource
(
    QTextStream&		stream,
    const QString&		varName,
    const QList<DlgWidget>&	zOrdering
)
{
    GenSrc( *this, stream, varName, zOrdering );
}

#endif // DlgSlider_included
